==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QComponentRemovedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a component is removed from an entity</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html">Qt3DCore::QComponentRemovedChange</a></p>
 */
public class QComponentRemovedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#QComponentRemovedChange-1">Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)</a></p>
     */
    @Deprecated
    public QComponentRemovedChange(io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity){
        super((QPrivateConstructor)null);
        initialize_native(this, component, entity);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentRemovedChange instance, io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#QComponentRemovedChange">Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)</a></p>
     */
    @Deprecated
    public QComponentRemovedChange(io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component){
        super((QPrivateConstructor)null);
        initialize_native(this, entity, component);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentRemovedChange instance, io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#componentId">Qt3DCore::QComponentRemovedChange::componentId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId componentId(){
        return componentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId componentId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#componentMetaObject">Qt3DCore::QComponentRemovedChange::componentMetaObject()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QMetaObject componentMetaObject(){
        return componentMetaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QMetaObject componentMetaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#entityId">Qt3DCore::QComponentRemovedChange::entityId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QComponentRemovedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QComponentRemovedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a component is removed from an entity</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html">Qt3DCore::QComponentRemovedChange</a></p>
 */
public class QComponentRemovedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#QComponentRemovedChange-1">Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)</a></p>
     */
    @Deprecated
    public QComponentRemovedChange(io.qt.qt3d.core.@Nullable QComponent component, io.qt.qt3d.core.@Nullable QEntity entity){
        super((QPrivateConstructor)null);
        initialize_native(this, component, entity);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentRemovedChange instance, io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#QComponentRemovedChange">Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)</a></p>
     */
    @Deprecated
    public QComponentRemovedChange(io.qt.qt3d.core.@Nullable QEntity entity, io.qt.qt3d.core.@Nullable QComponent component){
        super((QPrivateConstructor)null);
        initialize_native(this, entity, component);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentRemovedChange instance, io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#componentId">Qt3DCore::QComponentRemovedChange::componentId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId componentId(){
        return componentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId componentId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#componentMetaObject">Qt3DCore::QComponentRemovedChange::componentMetaObject()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject componentMetaObject(){
        return componentMetaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject componentMetaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentremovedchange.html#entityId">Qt3DCore::QComponentRemovedChange::entityId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QComponentRemovedChange(QPrivateConstructor p) { super(p); } 
    
}
